package vectors;

/**
 * Represents an ellipse
 * It is defined by an anchor point, a width and a height
 * It can be moved, scaled and rotated
 * 
 * @author rXp
 *
 */
public class Ellispe implements Move, Scale, Rotate {

	/**
	 * Distance between the 2 focus points
	 */
	private float dFoci;
	/**
	 * Length of the X axis of the ellipse
	 */
	private float width;
	/**
	 * Length of the Y axis of the ellipse
	 */
	private float height;
	/**
	 * Anchor point of the ellipse in 2D space
	 */
	private Point anchor = null;
	
	/**
	 * Constructor
	 * Create an ellipse
	 * 
	 * @param p Anchor point
	 * @param width Length of the X axis of the ellipse
	 * @param height Length of the Y axis of the ellipse
	 */
	public Ellispe(Point p, float width, float height){
		this.anchor = p;
		this.width = width;
		this.height = height;
		this.dFoci = getFoci();
	}
	
	private float getFoci(){
		return 2* (float) Math.sqrt(Math.pow(this.width/2,2) - Math.pow(this.height/2,2));
	}
	
	@Override
	public void rotate(float radian) {
		// TODO Auto-generated method stub

	}

	@Override
	public void scale(float scalar) {
		this.width*=scalar;
		this.height*=scalar;
		this.dFoci = getFoci();
	}

	@Override
	public void setLocation(Point p) {
		this.anchor.x = p.x;
		this.anchor.y = p.y;
	}

	@Override
	public void move(Vector2D v) {
		this.anchor.x += v.x;
		this.anchor.y += v.y;
	}

}
