package vectors;

/**
 * Represents a line in 2D space.
 * A line has a given length.
 * It is defined by an anchor point, a vector director and a scale.
 * It can be Moved, Rotated, Scaled, Normalized
 * @author rXp
 *
 */
public class Line2D extends Ray2D implements Scale, Normalize{
	
	/**
	 * Length of the line
	 */
	private float length = 1;
	
	/**
	 * Constructor
	 * Create a line
	 * 
	 * @param anchor Point from where the line originate
	 * @param director Vector dictating the direction of the ray
	 * @param scalar Length of the line
	 */
	public Line2D(Point anchor, Vector2D director, float length){
		super(anchor, director);
		this.length = length;
	}
	
	/**
	 * Constructor
	 * Create a line by giving the beginning point and ending point of the line
	 * The line will go from p1 to p2
	 * 
	 * @param p1 Beginning point of the line
	 * @param p2 Ending point of the line
	 */
	public Line2D(Point p1, Point p2){
		super(new Point(p1), new Vector2D(p2.x-p1.x,p2.y-p1.y));
	}
	
	/**
	 * Copy Constructor
	 * Copy the given line to create a new one
	 * 
	 * @param line Copied line
	 */
	public Line2D(Line2D line){
		this(line.anchor, line.director, line.length);
	}
	
	/**
	 * Getting the length of the line
	 * @return Length of the line
	 */
	public double getLenght(){
		return this.length;
	}

	@Override
	public void scale(float scalar) {
		this.length = scalar;
	}

	@Override
	public void normalize() {
		this.length = 1;
	}

}
