package vectors;

/**
 * Represents a point in 2D space.
 * The values are not limited by the resolution of the screen(then negative numbers are accepted).
 * This object is immutable.
 * @author rXp
 *
 */
public class Point{
	
	/**
	 * Position of the point in 2D space
	 * Negative values are accepted
	 */
	protected float x,y;	
	
	/**
	 * Default Constructor
	 * Create a point at the location 0,0 in 2D space
	 */
	public Point(){}
	
	/**
	 * Constructor
	 * Create a point at the given location in 2D space
	 * 
	 * @param x Position of the point in the X axis
	 * @param y Position of the point in the Y axis
	 */
	public Point(float x,float y){
		this.x = x;
		this.y = y;
	}
	
	/**
	 * Copy constructor
	 * Create a point at the same location of the given point
	 * (Copy the given point)
	 * 
	 * @param p Point copied
	 */
	public Point(Point p){
		this.x = p.x;
		this.y = p.y;
	}
	
	/**
	 * Get the position in X of the point
	 * 
	 * @return float - Position in X of the point 
	 */
	public double getX(){
		return x;
	}
	
	/**
	 * Get the position in Y of the point
	 * 
	 * @return float - Position in Y of the point 
	 */
	public double getY(){
		return y;
	}

    public boolean equals(Object o){
    	Point p2 = null;
    	if(o instanceof Point)
    		p2 = (Point) o;
    	else
    		return false;
    	
    	return (Float.compare(this.x,p2.x)==0 && Float.compare(this.y,p2.y)==0);
    }

}
