package vectors;

/**
 * Represents a ray in 2D space.
 * A ray is a line with a infinite length.
 * It is defined by an anchor point and a vector director.
 * It can be Moved, Rotated
 * @author rXp
 *
 */
public class Ray2D implements Move, Rotate{

	/**
	 * Point from where the ray originate
	 */
	protected Point anchor = null;
	/**
	 * Vector dictating the direction of the ray
	 */
	protected Vector2D director = null;
	
	/**
	 * Constructor
	 * Create a ray
	 * 
	 * @param anchor Point from where the ray originate
	 * @param director Vector dictating the direction of the ray
	 */
	public Ray2D(Point anchor, Vector2D director) {
		this.anchor = anchor;
		this.director = director;
	}
	
	/**
	 * Get the anchor point
	 * 
	 * @return The anchor point
	 */
	public Point getAnchorPoint(){
		return this.anchor;
	}
	
	/**
	 * Get the vector director
	 * 
	 * @return The vector director
	 */
	public Vector2D getVectorDirector(){
		return this.director;
	}
	
	@Override
	public void rotate(float radian) {
		this.director.x = (float) (this.director.x*Math.cos(radian)-this.director.y*Math.sin(radian));
		this.director.y = (float) (this.director.y*Math.cos(radian)+this.director.x*Math.sin(radian));
	}

	@Override
	public void setLocation(Point p) {
		this.anchor.x = p.x;
		this.anchor.y = p.y;
	}

	@Override
	public void move(Vector2D v) {
		this.anchor.x += v.x;
		this.anchor.y += v.y;
	}
	

}
