package vectors;

/**
 * Represents Vector in 2D space
 * The values are not limited by the resolution of the screen(then negative numbers are accepted).
 * It can be Scaled, Normalized, Rotated
 * 
 * @author rXp
 *
 */
public class Vector2D extends Point implements Scale, Normalize, Rotate{

	/**
	 * Default Constructor
	 * Create a null vector
	 */
	public Vector2D(){}
	
	/**
	 * Constructor
	 * Create a vector at the given location in 2D space
	 * 
	 * @param x Component of the vector in the X axis
	 * @param y Component of the vector in the Y axis
	 */
	public Vector2D(float x,float y){
		super(x,y);
	}
	
	/**
	 * Copy constructor
	 * Create a vector having the same component than the given vector
	 * (Copy the given vector)
	 * 
	 * @param p Vector copied
	 */
	public Vector2D(Vector2D v){
		super(v);
	}
	
	/**
	 * Get the norm (length) of the vector
	 * @return double - the norm of the vector
	 */
	public double getNorm(){
		return Math.sqrt(x*x+y*y);
	}
	
	/**
	 * Adds another vector to this one
	 * @param v Vector to add
	 */
	public void addVector2D(Vector2D v){
		this.x += v.x;
		this.y += v.y;
	}
	
	public boolean equals(Object o){
    	Vector2D v = null;
    	if(o instanceof Vector2D)
    		v = (Vector2D) o;
    	else
    		return false;
    	
    	return (Float.compare(this.x,v.x)==0 && Float.compare(this.y,v.y)==0);
    }

	@Override
	public void scale(float scalar) {
		this.x*=scalar;
		this.y*=scalar;
	}

	@Override
	public void normalize() {
		double norm = getNorm();
		this.x/=norm;
		this.y/=norm;
	}

	@Override
	public void rotate(float radian) {
		this.x = (float) (this.x*Math.cos(radian)-this.y*Math.sin(radian));
		this.y = (float) (this.y*Math.cos(radian)+this.x*Math.sin(radian));
	}
	
	

}
